@@ -13,14 +13,14 @@ A container for functions for the ack program.
 
 =head1 VERSION
 
-Version 2.999_04
+Version 2.999_05
 
 =cut
 
 our $VERSION;
 our $COPYRIGHT;
 BEGIN {
-    $VERSION = '2.999_04';
+    $VERSION = '2.999_05';
     $COPYRIGHT = 'Copyright 2005-2018 Andy Lester.';
 }
 our $STANDALONE = 0;
@@ -288,9 +288,9 @@ File presentation:
                                 files.  (default: on when used interactively)
   --group                       Same as --heading --break
   --nogroup                     Same as --noheading --nobreak
-  --[no]proximate               Separate match output with blank lines unless
-                                they are on adjacent lines.
-  -P                            Negates --proximate.
+  -p, --proximate=LINES         Separate match output with blank lines unless
+                                they are within LINES lines from each other.
+  -P, --proximate=0             Negates --proximate.
   --[no]underline               Print a line of carets under the matched text.
   --[no]color, --[no]colour     Highlight the matching text (default: on unless
                                 output is redirected, or on Windows)
